@@ -599,44 +599,46 @@
 ;;;; Basic functions
 ;;;; Important: All these work with strings because there is no native number base7 system in Scheme.
 
+;Checks if a string is a lilypond note compatible with (d-ChangeChordNotes)
+;(define (ANS-7::IsLily?)
+;	
+;)
+
 (define (ANS-7::Ly2Ans lilynote) ;wants string, returns string
 	(hashq-ref ANS-7::Base7NoteTableR (string->symbol lilynote))
 )
 
-;TODO: Chordtranslation is missing. But keep the single note functions, will be faster.
-
 (define (ANS-7::Ans2Ly ansNote) ;wants string, returns strings
 	(hashq-ref ANS-7::Base7NoteTable (string->number ansNote))
 )
 
-(define (ANS-7::GetChordNotes); For singles and chords. Returns string of ANS-7 notes as pseudo-list divided by space: : "3500 4030 4200". 
-	(define newList #f)
-	(set! newList (string-tokenize (d-GetNotes)) )
-
-	(let transformChordList ((i 0) )
-	(if (<= i (-(length newList )1)) 
-		(begin
-			(set! newList (replace-nth newList i (ANS-7::Ly2Ans (list-ref newList i) )))
-			(transformChordList (+ i 1)))))
-
-	(string-join newList)
+(define (ANS-7::GetChordNotes); For singles and chords. Returns a list of ANS-7 string-numbers as chord: ("3500" "4030" "4200") 
+	(define lilylist (string-tokenize (d-GetNotes)))
+	(map ANS-7::Ly2Ans lilylist)
 )
 
-(define* (ANS-7::InsertNotes ansNotes #:optional (duration #f)); wants string of ANS-7 notes string, can be a pseudo-list divided by space: "3500 4030 4200". Optional duration. returns #t or #f
-	(if (string? ansNotes)
-		(begin (d-InsertA) (ANS-7::ChangeChordNotes ansNotes)))
+
+(define* (ANS-7::InsertNotes ansNotes #:optional (dots #f) (duration #f) ); wants a string or  a list of ANS-7 note-strings as chord ("3500" "4030" "4200"). Optional duration and number of dots. returns #t or #f
+	;TODO: Check if these are valid notes.
+	(d-InsertA)
+	(d-MoveCursorLeft)
+	(ANS-7::ChangeChordNotes ansNotes)
+	(if duration  ;If user gave duration parameter. Does not test if the duration is a valid number
+			(eval-string (string-append "(d-Change" (number->string duration) ")"))) ; FIXME eval string should be gone
+	(if (and dots (not (= dots 0))) ;If the user gave 0 as durations ignore that as well
+			(let loop ((count 0)) 
+				(d-AddDot)
+				(if (< count (- dots 1))
+				(loop (+ 1 count)))))
+	(d-MoveCursorRight)
 )
 
-(define (ANS-7::ChangeChordNotes ansNotes); wants string of ANS-7 notes, can be a pseudo-list divided by space: "c' e'' gis,". 
-	(define newList #f)
-	(set! newList (string-tokenize ansNotes) )
-
-	(let transformChordList ((i 0) )
-	(if (<= i (-(length newList )1)) 
-		(begin
-			(set! newList (replace-nth newList i (ANS-7::Ans2Ly (list-ref newList i) )))
-			(transformChordList (+ i 1)))))
-
+(define (ANS-7::ChangeChordNotes ansNotes); wants a string or list of ANS-7 note-strings ("3500" "4030" "4200") 
+	(define newList '())
+	(if (list? ansNotes)
+		#t
+		(set! ansNotes (list ansNotes)))
+	(set! newList (map ANS-7::Ans2Ly ansNotes))
 	(d-ChangeChordNotes (string-join newList))
 )
 
@@ -644,39 +646,138 @@
 	(string-append (string-drop-right ansNote  2  ) "00") 
 )
 
-(define (ANS-7::+ one two); wants two strings 
-	(number->string (+	(string->number one 7) (string->number two 7)) 7)
+;Alteration adds a sharp, flat or nothing to an ans-7 note. Returns an ans-7 number-string note. Wants an ans-7 number-string and a procedure that will return either 0, 1 or -1. 
+(define (ANS-7::Alteration inputstring caserator)
+	(case caserator
+	  ((0)		inputstring) ; natural, no change
+	  ((1)		(ANS-7::+ inputstring  "30")) ;sharp
+	  ((-1)		(ANS-7::+ inputstring  "20")) ;flat
+	  (else   #f ) ; someone might introduce some insane feature in the future where you can add doublecrosses or similar to a keysig. Or maybe there is even a real usage for micotonals like turkish maqam.
+	 )
 )
 
-(define (ANS-7::- one two); wants two strings 
-	(number->string (-	(string->number one 7) (string->number two 7)) 7)
+; For calculations convert all base 7 to decimal first and before returning return them back to base7.
+; (string->number "str" 7) converts a string which is supposed to be a base7 value to a decial integer
+; (number->string n 7) converts a decimal number to a string-"number" which is base7. 
+
+(define (ANS-7::number->string n)
+(number->string n 7))
+
+(define (ANS-7::string->number n)
+(string->number n 7))
+
+(define (ANS-7::math op nums); wants  strings
+ (ANS-7::number->string (apply op (map ANS-7::string->number nums)))
 )
 
-;Calculate the a diatonic step up or down and keep it in scale / according to the prevailing keysignature
-;wants lilypond and returns the next diatonic step in lilypond. Defaults to upward step. There is an optional bool parameter, if set to #t  the step goes down.
-(define* (ANS-7::CalculateDiatonicStep sourceLilypond #:optional (down #f)) ;
-       (define listi (string-tokenize(d-GetPrevailingKeysig)))
-       
-       (let calc ((sourceNumber 0)(nextNumber 0) (thirdDigit 0) )
-		(set! sourceNumber (ANS-7::Ly2Ans sourceLilypond))
-		(set! nextNumber (ANS-7::MakeWhiteKey sourceNumber))
-		(if down
-			(set! nextNumber (ANS-7::- nextNumber  "100"))
-			(set! nextNumber (ANS-7::+ nextNumber  "100"))
-		)
+(define (ANS-7::+ . nums )  (ANS-7::math + nums))
+(define (ANS-7::- . nums )  (ANS-7::math - nums))
+(define (ANS-7::* . nums )  (ANS-7::math * nums))
+(define (ANS-7::/ . nums )  (ANS-7::math / nums))
 
-		(set! thirdDigit
-		; always take the third-last digit which shows the note as "white key" and regardless of the octave.  This is done for the target-note, not for the origin.
-			(string-ref nextNumber (- (string-length nextNumber) 3) )) ; string-ref returns char, not string.
 
-		(set! thirdDigit (string->number (string thirdDigit))) ; transfer the char to a real number
-			
-		 (case (string->number (list-ref listi thirdDigit))
-		   ((0)		(set! nextNumber (ANS-7::+ nextNumber  "0"))) ; natural
-		   ((1)		(set! nextNumber (ANS-7::+ nextNumber  "30"))) ;sharp
-		   ((-1)		(set! nextNumber (ANS-7::+ nextNumber  "20"))) ;flat
-		   (else   #f ) ; someone might introduce some insane feature in the future where you can add doublecrosses or similar to a keysig. Or maybe there is even a real usage for micotonals like turkish maqam.
-		  )
-		   (ANS-7::Ans2Ly nextNumber) ; Return note as Lilypond-syntax
-       )    
+(define (ANS-7::CalculateRealOctaveUp sourceANS) ; Works with one string
+	(ANS-7::+ sourceANS "1000")
 )
+
+(define (ANS-7::CalculateRealOctaveDown sourceANS) ; Works with one string
+	(ANS-7::- sourceANS "1000")
+)
+
+;Make diatonic. Looks ups the prevailing keysignature and returns the correct diatonic value for a given note.
+(define (ANS-7::MakeDiatonic sourceANS)
+	(define keysiglist (string-tokenize (d-GetPrevailingKeysig)))
+	(define nextnumber (ANS-7::MakeWhiteKey sourceANS))
+	(define (calcThirdDigit nextnumber)  ; check which pitch of note we got after just transposing (no keysig so far) the sourceANS. The third digit, right-to-left, indicates the pitch without sharp/flat or octave. 
+		(string->number (string (string-ref nextnumber (- (string-length nextnumber) 3) ))) ; conversion chain to get a number
+	)	
+		
+	;At last compare our target-pitch with the current keysignature. If the target "slot" is altered by a keysig we need to change our target-pitch according to the keysig.	
+	(ANS-7::Alteration nextnumber (string->number (list-ref keysiglist (calcThirdDigit nextnumber))))
+)
+
+(define (ANS-7::CalculateDiatonicStepUp sourceANS) (ANS-7::MakeDiatonic (ANS-7::+ sourceANS "100")))
+(define (ANS-7::CalculateDiatonicStepDown sourceANS ) (ANS-7::MakeDiatonic (ANS-7::- sourceANS "100")))
+
+;;;;Random note generation
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+               
+; Generates a random note within a given range. The range includes both values.
+(define (ANS-7::random from to)
+	(let (
+		 (from (string->number (ANS-7::/ from "100") 7))
+		 (to (string->number (ANS-7::/ to "100") 7))
+		 (rand "0")
+		 )
+	(set! to (+ 1 (- to from))) ;+1 to include the last, given value.
+	(set! rand (number->string (+ from (random to)) 7)) ; Convert back to base7
+	(ANS-7::* rand "100")
+	)
+)
+
+;Random note generator, respects the keysignature. Insert an optional range, default is all 56 diatonic notes.
+(define* (ANS-7::RandomDiatonic #:optional (from "0") (to "10600"))
+	(ANS-7::MakeDiatonic (ANS-7::random from to))	
+)
+
+;Random note generator, one of each possible chromatic notes or optional range. Same probability for natural, flat or sharp.
+(define* (ANS-7::RandomChromatic #:optional (from "0") (to "10600"))
+	(define rand (- (random 3) 1))	; -1, 0 or 1
+	(ANS-7::Alteration (ANS-7::random from to) rand) 
+)  
+
+;Smart note generator, looks at the clef and returns only notes in a reasonable range
+
+;Takes a list of ans-7 notes, shuffles the members and inserts them as new notes. no chords possible
+(define (ANS-7::InsertListRandomly ans7list)
+	(define shuffledlist (merge-shuffle-list ans7list))
+	(for-each ANS-7::InsertNotes shuffledlist)
+)
+
+;Takes a list of ans-7 notes and randomly pick one to insert. The member remains in the list
+(define (ANS-7::InsertMemberRandomly ans7list)
+	(define rnd (random (length ans7list) ))
+	(ANS-7::InsertNotes (list (list-ref ans7list rnd) ))
+)
+
+;;;; The pillar of filth
+;;;; To calculate real and correct intervals you need the pillar of fifth with 35 steps for each realistic notename (and 4 unrealistic ones)
+;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define ANS-7::PillarOfFifth (list "feses" "ceses" "geses" "deses" "asas" "eses" "bes" "fes" "ces" "ges" "des" "as" "es" "b" "f" "c" "g" "d" "a" "e" "h" "fis" "cis" "gis" "dis" "ais" "eis" "his" "fisis" "cisis" "gisis" "disis" "aisis" "eisis" "hisis"))
+
+; Tell the number of steps up or down 
+(define (ANS-7::IntervalGetSteps target)
+	(cond
+		((or (eq? target 'p1) (eq? target 'P1)) 0)			
+		((eq? target 'm2) -5)			
+		((eq? target 'M2) 2)			
+		((eq? target 'm3) -3)
+		((eq? target 'M3) 4)	
+		((or (eq? target 'p4) (eq? target 'P4)) -1)	
+		((or (eq? target 't) (eq? target 'T)) 6)
+		((or (eq? target 'p5) (eq? target 'P5)) 1)
+		((eq? target 'm6) -4)			
+		((eq? target 'M6) 3)		
+		((eq? target 'm7) -2)	
+		((eq? target 'M7) 5)		
+		(else (display "Error or Interval not supported yet."))
+	)		
+)
+
+(define (ANS-7::IntervalCalcUp root target)
+ (let( (targ (ANS-7::IntervalGetSteps target)) )	
+  (list-ref ANS-7::PillarOfFifth (+ root targ))   
+ )
+)
+	
+(define (ANS-7::IntervalCalcDown root target)
+ (let( (targ (ANS-7::IntervalGetSteps target)) )
+  (list-ref ANS-7::PillarOfFifth (+ root (* -1 targ)))   
+ )
+)
+
+
+;(display (ANS-7::IntervalCalcUp 17 'm2) )(newline)
+;(display (ANS-7::IntervalCalcDown 15 'm2) )(newline)
