@@ -1,7 +1,19 @@
+
+(define Denemo #t)
+
+(use-modules (srfi srfi-1))
+(use-modules (srfi srfi-8))
 (use-modules (srfi srfi-13))
 (use-modules (ice-9 regex))
 (use-modules (ice-9 optargs))
 (load "ans-7.scm")
+(load "notationmagick.scm")
+
+; Create a seed for (random int) one time Denemo starts. The seed is altered by random itself afterwards.
+(let ((time (gettimeofday)))
+    (set! *random-state*
+        (seed->random-state (+ (car time)
+                 (cdr time)))))
 
 (define DenemoKeypressActivatedCommand #f);;;is true while a keyboard shortcut is invoking a script, unless the script has set it to #f
 
@@ -86,7 +98,10 @@
 ;Return values are the return values the script itself gives.
 ;Example: (SingleAndSelectionSwitcher  "(d-ChangeDurationByFactorTwo *)" "(d-ChangeDurationByFactorTwo *)")
 
-(define (SingleAndSelectionSwitcher commandsingle commandselection)
+(define* (SingleAndSelectionSwitcher commandsingle #:optional (commandselection commandsingle)) ; Amazingly commandsingle is already defined on spot so that it can be used again in the same line to define commandselection 
+(if (not commandselection)
+	(define commandselection commandsingle)
+)
 (d-PushPosition)
 (if (and DenemoPref_applytoselection (d-GoToSelectionStart))
 (begin
@@ -156,6 +171,20 @@
 ;(define cue- "")
 
 
+;;;;;;;;;;;;;;;;hardcode default number keys to Insert Note in Composer Mode
+	(define wrap:Op0 "#f")(set! wrap:Op0 "(d-Insert0)")
+	(define wrap:Op1 "#f")(set! wrap:Op1 "(d-Insert1)")
+	(define wrap:Op2 "#f")(set! wrap:Op2 "(d-Insert2)")
+	(define wrap:Op3 "#f")(set! wrap:Op3 "(d-Insert3)")
+	(define wrap:Op4 "#f")(set! wrap:Op4 "(d-Insert4)")
+	(define wrap:Op5 "#f")(set! wrap:Op5 "(d-Insert5)")
+	(define wrap:Op6 "#f")(set! wrap:Op6 "(d-Insert6)")
+	(define wrap:Op7 "#f")(set! wrap:Op7 "(d-Insert7)")
+	(define wrap:Op8 "#f")(set! wrap:Op8 "(d-Insert8)")
+	(define wrap:Op9 "#f")(set! wrap:Op9 "#f")
+
+	
+
 ;;;;;;;;;;;;;;;; Double-Stroke for sequencing keypresses. By Nils Gey June 2010
 ;One parameter for the GUI-version or help window. This is the version that appears if someone clicks on the menu version.
 ;Ten optional parameters given as strings which can be only MENU commands: complete scheme syntax with (d-), but as string "" and with escaped \" in them. They return #f if not defined
@@ -164,12 +193,6 @@
 
 (define* (doublestroke gui-version #:optional (first "#f") (second "#f") (third "#f") (fourth "#f") (fifth "#f") (sixth "#f") (seventh "#f") (eighth "#f") (ninth "#f") (tenth "#f"))
 
-;Create a keybinding for a non-"#f" command, trimming (d- ... ) first.  Used for the [Return] variant.
-(define (doublestroke::bind action numberasstring) 
-		(if (not (string=? action "#f" ))
-			(d-AddKeybinding  (substring action 3 (- (string-length action) 1) )  numberasstring)
-			(d-AddKeybinding (d-GetId "NoOp") numberasstring)))
-
 ; Create a fallback-GUI which just lists all commands as radio-buttons. Used for the [space] variant.
 (define (doublestroke::fallbackgui)
 	(define doublestroke::result #f)
@@ -206,16 +229,16 @@
 		((#{0}#)  (eval-string tenth))
 		((space)  (doublestroke::invokegui))
 		((Return) (begin
-				(doublestroke::bind first "1")
-				(doublestroke::bind second "2")
-				(doublestroke::bind third "3")
-				(doublestroke::bind fourth "4")
-				(doublestroke::bind fifth "5")
-				(doublestroke::bind sixth "6")
-				(doublestroke::bind seventh "7")
-				(doublestroke::bind eighth "8")
-				(doublestroke::bind ninth "9")								
-				(doublestroke::bind tenth "0")
+				(set! wrap:Op1 first)
+				(set! wrap:Op2 second)
+				(set! wrap:Op3 third)
+				(set! wrap:Op4 fourth)
+				(set! wrap:Op5 fifth)
+				(set! wrap:Op6 sixth)
+				(set! wrap:Op7 seventh)
+				(set! wrap:Op8 eighth)
+				(set! wrap:Op9 ninth)
+				(set! wrap:Op0 tenth)
 				))
 		(else #f))
 	  (set! DenemoKeypressActivatedCommand #f))
@@ -1099,8 +1122,7 @@
   )
   
  (define (measurebreak)
- 
-   (if (d-GetClipObjType 1 0) ;Multistaff?
+    (if (d-GetClipObjType 1 0) ;Multistaff?
 	(begin (d-InsertMeasureAfter) (nextplease))  ;Yes it is, just go on and paste
       
         (if  (and (not (d-GetClipObjType 1 0)) (= 8 (d-GetClipObjType 0 0)) (= 0 count)) ; User might have copied a leading measurebreak by accident. Ignore this. Else go on and try to detect empty measures or add measures.
@@ -1122,16 +1144,32 @@
  )
   
   
- ; For clipboards smaller than one full measure Denemo will automatically add barlines if needed 
- (if (and (d-GetClipObjType staff count) (string-ci=?  (d-GetType) "Appending")  (not paste::break?) (MeasureFillStatus))
+; For clipboards smaller than one full measure Denemo will automatically add a barline before an object if needed 
+;;; The inline (or ...) is for the case that a non-note is at the start or end of clipboard. If its at the start the measure is allowed to break if pasting to a full measure. If its not the first item (e.g. the last) the measure is not allowed to break before. But not if the first one is the only one!
+
+ 
+ (if (and  
+	(d-GetClipObjType staff count) ; valid paste?
+	(not (and ; Only breaks for more than one object in the clipboard
+	 	  (not (d-GetClipObjType staff 1))
+	 	  (= count 0)
+ 	))    
+ 	(or (= 0 (d-GetClipObjType staff count))   ; Only break before notes except its the first item in list
+ 	      (= count 0)
+ 	) 	 		       
+ 	(string-ci=?  (d-GetType) "Appending") 
+ 	(not paste::break?) 
+ 	(MeasureFillStatus)) ; if conditions end
+ 	
             (if (d-MoveToMeasureRight) ; End of Staff?
 			(if (MeasureEmpty?) 
 				#t
 				(d-InsertMeasureBefore) ) 
-			(d-InsertMeasureAfter)))
- 
+			(d-InsertMeasureAfter))
+	)
   
 ; The real action: Get the type of clipboard-object and decide what to do. In most cases it will be just pasting but someties special behaviour is needed. Because pasting a staffbreak does not actually moves the cursor to the new staff so this has to be done manually.
+ 
  (case (d-GetClipObjType staff count) 
 	((#f) (endthis) ) ; No object left. Means "no clipboard", too.
 	((-1) (display "No object")); should not happen anymore
@@ -1159,4 +1197,90 @@
  ))
  
  ;;;;;;;;;;;;;;;;;;;;;;;; Paste End
+ 
+ ;;;; Shuffling Sequences
+;;; http://mumble.net/~campbell/scheme/shuffle.scm
+;;; This code is written by Taylor R. Campbell and placed in the Public
+;;; Domain.  All warranties are disclaimed.
+;;; This uses SRFIs 1 (list-lib) and 8 (receive).
 
+;;;; Merge Shuffle
+;;; Partition the list into two equal halves; shuffle the two halves,
+;;; and then merge them by randomly choosing which half to select the
+;;; next element from.
+
+(define (flip-coin) 
+	(if (= 1 (random 2))
+		#t
+		#f))
+
+
+(define (merge-shuffle-list list)
+
+  (define (merge a b)
+    (cond ((not (pair? a)) b)
+          ((not (pair? b)) a)
+          (else
+           (if (flip-coin)
+               (cons (car a) (merge (cdr a) b))
+               (cons (car b) (merge a (cdr b)))))))
+
+  (define (partition list a b)
+    (let ((next (cdr list))
+          (a b)
+          (b (cons (car list) a)))
+      (if (null-list? next)
+          (values a b)
+          (partition next a b))))
+
+  (if (null-list? list)
+      '()
+      (let shuffle ((list list))
+        (if (null-list? (cdr list))
+            list
+            (receive (a b) (partition list '() '())
+              (merge (shuffle a) (shuffle b)))))))
+
+;;; This has *far* too many SET-CDR!s.
+
+(define (merge-shuffle-list! list)
+
+  (define (merge! a b)
+    (cond ((null-list? a)       b)
+          ((null-list? b)       a)
+          ((flip-coin)          (%merge! a b) a)
+          (else                 (%merge! b a) b)))
+
+  (define (%merge! a b)
+    (cond ((null-list? (cdr a))
+           (set-cdr! a b))
+          ((flip-coin)
+           (%merge! (cdr a) b))
+          (else
+           (%merge! b (let ((next (cdr a)))
+                        (set-cdr! a b)
+                        next)))))
+
+  (define (partition! list a b)
+    (let ((next (cdr list)))
+      (set-cdr! list a)
+      (if (null-list? next)
+          (values list b)
+          (partition! next b list))))
+
+  (if (null-list? list)
+      '()
+      (let shuffle! ((list list))
+        (if (null-list? (cdr list))
+            list
+            (receive (a b) (partition! list '() '())
+              (merge! (shuffle! a) (shuffle! b)))))))
+;;;;;;;;;;;;;;; End Shuffle
+
+
+
+(define (lyimport::load-file pathname filename)
+  (load (string-append DENEMO_ACTIONS_DIR "lyimport.scm"))
+  (set! lyimport::pathname pathname) 
+  (set! lyimport::filename filename)
+  (eval-string (lyimport::import)))
