@@ -26,8 +26,9 @@
 #define DENEMO_TEXTEDITOR_TAG "texteditor"
 
 /* values for is_grace attribute of CHORD type */
-#define GRACE_SECTION (1<<0) /*Note is in grace section */
+#define GRACE_SECTION (1<<0) /*Note is in grace section; For backward compatibility with old grace object types */
 #define GRACED_NOTE (1<<1) /*Note has been individually designated a grace note */
+#define ENDGRACE (1<<2) /*Note is last grace note in a group */
 
 
 typedef void (*GActionCallback) (GtkAction *action, gpointer data);
@@ -303,6 +304,9 @@ typedef struct DenemoKeymap
                                   //The keystring is the output of
   				  //dnm_accelerator_name()
   GHashTable *cursors;//hashtable linking GdkEvent state to a cursor that should be used in that state
+ 
+  GHashTable *continuations_table;//hashtable giving possible continuations for two-keybindings
+
 }keymap;
 
 typedef struct MidiBuffer
@@ -352,10 +356,12 @@ typedef struct DenemoPrefs
   gboolean createclones;
   gint mode; /**< mode to start in */
   gboolean modal;/**< whether mode-switching menu is desired */
+  gboolean persistence;/**< whether Denemo should re-use settings over sessions */
   gint zoom; /**< percent zoom  1-100 */
   gint system_height; /**< percent of display height per system  1-100 */
   gboolean cursor_highlight; /** Should the cursor be highlighted */
-
+  
+  gboolean toolbar; /**< makes the toolbar visible */
   gboolean playback_controls; /**< makes the playback controls visible */
   gboolean midi_in_controls; /**< makes the midi in controls visible */
   gboolean articulation_palette; /**< makes the articulation pallete visible */
@@ -917,6 +923,7 @@ struct DenemoRoot
   GList *guis; /**< the list of DenemoGUI objects, representing pieces of music
 		  simultaneously open */
   DenemoPrefs prefs;  /**< Preferences stored on exit and re-loaded on startup */
+  
   gint autosaveid;/**< autosave timer id: only one musical score is being autosaved at present */
   gint accelerator_status; /**< if the accelerators have been saved, or extra ones for special keys defined  */
   GtkUIManager *ui_manager;  /**< UI manager */
@@ -937,7 +944,7 @@ struct DenemoRoot
   GtkWidget *EditModeMenu;/**< Menu to give the note editing facilities in Edit mode */
   GtkWidget *ModelessMenu;/**< Menu to give the note editing facilities when used without modes */
   gboolean QuickShortcutEdits;/**< TRUE if pressing a key while hovering over a menu item sets a shortcut */
-
+  GList *continuations;
   struct RhythmPattern *singleton_rhythms[256]; /**< rhythm patterns for the EntryToolbar */
   gboolean ScriptRecording;/**< TRUE when menuitems presses are being recorded as scheme script*/
   GtkWidget *ScriptView; /**< a GtkTextView containing a scheme script */
