@@ -54,16 +54,7 @@ void nextrhythm(DenemoGUI *gui) {
     return;
   if(gui->currhythm==NULL)
     gui->currhythm = g_list_last(gui->rhythms);
-#if 0
-  gtk_widget_set_state(((RhythmPattern *)gui->currhythm->data)->button, GTK_STATE_NORMAL);
-#else
-
-  {GdkColor thecolor;
-    gdk_color_parse ("gray", &thecolor);
-    gtk_widget_modify_bg (gtk_tool_button_get_label_widget(GTK_TOOL_BUTTON(((RhythmPattern *)gui->currhythm->data)->button)), GTK_STATE_NORMAL, &thecolor);
-  }
-
-#endif
+  unhighlight_rhythm((RhythmPattern *)gui->currhythm->data);
   if(gui->currhythm->next)
     gui->currhythm = gui->currhythm->next;
   else
@@ -470,9 +461,14 @@ swapstaffs (GtkAction *action, gpointer param)
   if (gui->si->currentstaff && gui->si->currentstaff->prev)
     {
       DenemoStaff *temp;
-      temp = gui->si->currentstaff->data;
-      if(temp->context==DENEMO_NONE ||
-	confirm("A context is set on this staff", "You will need to alter the staff->properties->context of this and the previous staff; Proceed?")) {
+      //if this is a staff with no voices extra voices on it then swap
+      if( ((DenemoStaff *)gui->si->currentstaff->data)->voicenumber==1 &&
+	  ( (gui->si->currentstaff->next==NULL) || 
+	    ((DenemoStaff *)gui->si->currentstaff->next->data)->voicenumber<2)) {
+
+	temp = gui->si->currentstaff->data;
+	if(temp->context==DENEMO_NONE ||
+	   confirm("A context is set on this staff", "You will need to alter the staff->properties->context of this and the previous staff; Proceed?")) {
 	  gui->si->currentstaff->data = gui->si->currentstaff->prev->data;
 	  gui->si->currentstaff->prev->data = temp;
 	  gui->si->currentstaffnum--;
@@ -484,6 +480,9 @@ swapstaffs (GtkAction *action, gpointer param)
 	  displayhelper(gui);
 	  return TRUE;
 	}
+      }
+      else
+	warningdialog("Split off voices from this staff first");
     }
   else
     warningdialog("There is no previous staff to swap with");
@@ -516,7 +515,7 @@ splitstaffs (GtkAction *action, gpointer param)
       return TRUE;
     }
   else
-    warningdialog("There is no voice to split from");
+    warningdialog("There is no voice below this one to split from");
   return FALSE;
 }
 
@@ -937,7 +936,7 @@ static gboolean prev_object_is_rhythm (DenemoGUI *gui) {
 
 /* insert a note into the score at the current cursor position following the current rhythm step */
 
-void insert_note(DenemoGUI *gui)  {
+static void insert_note_following_pattern(DenemoGUI *gui)  {
 #define g  (gui->rstep)
   if((gui->mode&(INPUTEDIT|INPUTINSERT)) && g) {
     GList *start = g;
@@ -1013,7 +1012,7 @@ shiftcursor (DenemoGUI  *gui, gint note_value)
     }  
   } else
     /* in INSERT (or EDIT and appending) we insert a note using the next step of the rhythm pattern */
-    insert_note(gui);
+    insert_note_following_pattern(gui);
 
 }
 
@@ -1311,7 +1310,7 @@ insert_chordnote (DenemoGUI *gui){
   if(gui->si->currentobject && (curObj = Denemo.gui->si->currentobject->data) && (curObj->type==CHORD) )
     notechange(gui->si, FALSE);
   else
-    insert_note(gui);
+    insert_note_following_pattern(gui);
   return TRUE;
 }
 
@@ -1779,7 +1778,7 @@ dnm_deleteobject (DenemoScore * si)
   if(curmudelaobj==NULL)
     return;
   /* when tone_store is active, act on that, not the staff itself */
-
+#ifdef _HAVE_PORTAUDIO_
   if (((DenemoStaff*)si->currentstaff->data)->tone_store) {
     if(si->currentobject &&
        ((DenemoObject*)(si->currentobject->data))->type==CHORD){
@@ -1787,7 +1786,7 @@ dnm_deleteobject (DenemoScore * si)
 	return;
     }
   }
-
+#endif
   if(curmudelaobj->type==LILYDIRECTIVE && ((lilydirective *)curmudelaobj->object)->locked)
     if(!confirm("This LilyPond insert is locked","Really delete it?"))
       return;
