@@ -20,7 +20,6 @@
 #include "staffops.h"
 #include "utils.h"
 #include "exportlilypond.h"	/* to generate lily text for display */
-#include "lyparserfuncs.h"	/* to generate lily text for display */
 #include "pitchentry.h"
 #include "lyric.h"
 #include "midi.h"
@@ -104,7 +103,7 @@ struct infotopass
   gint measurenum;//would need measurenum_adj to allow control of numbering after pickup etc...
   gint staffnum;
   gint top_y;
-  //gint y;
+  gint last_gap;//horizontal gap from last object
   gint markx1, markx2;
   gint marky1, marky2;
   gboolean line_end;//set true when an object is drawn off the right hand edge
@@ -224,14 +223,18 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
 
 
   /* The current note, rest, etc. being painted */
-  gint extra;
+ 
   if(mudelaitem == Denemo.gui->si->playingnow)
     itp->playposition = x + mudelaitem->x;
 
   if(mudelaitem == itp->startobj)
-    itp->startposition = x + mudelaitem->x +  mudelaitem->minpixelsalloted;
+    itp->startposition = x + mudelaitem->x + mudelaitem->minpixelsalloted; 
+#if 0
+ if(itp->startobj==NULL && itp->startposition<=0)
+   itp->startposition = x;
+#endif
   if(mudelaitem == itp->endobj)
-    itp->endposition = x + mudelaitem->x;
+    itp->endposition = x + mudelaitem->x + mudelaitem->minpixelsalloted;
 
   //g_print("item %p draw at %d\n", mudelaitem, itp->playposition);
   // if (!greengc)
@@ -411,6 +414,10 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
       /* Nothing */
       break;
     }
+
+  gint extra = MAX (mudelaitem->minpixelsalloted,
+		    space_after (mudelaitem->durinticks,
+				 itp->wholenotewidth));
   if (si->currentobject == curobj)
     {				/* Draw the cursor */
       /* Determine if it needs to be red or not */
@@ -422,22 +429,20 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
 	  (mudelaitem->starttickofnextnote > itp->tickspermeasure);
       if (si->cursor_appending)
 	{
-	  extra = MAX (mudelaitem->minpixelsalloted,
-		       space_after (mudelaitem->durinticks,
-				    itp->wholenotewidth));
-	  draw_cursor (cr, si, x + mudelaitem->x + extra, y,
+
+	  draw_cursor (cr, si, x + mudelaitem->x + extra, y, ((itp->curmeasure->next!=NULL) && (objnode *) itp->curmeasure->next->data)?-1:1 /*itp->last_gap */,
 		       gui->mode, si->cursorclef);
 	  memcpy (si->cursoraccs, itp->curaccs, SEVENGINTS);
 	}
       else
 	{
-	  draw_cursor (cr, si, x + mudelaitem->x, y, gui->mode,
+	  draw_cursor (cr, si, x + mudelaitem->x, y, itp->last_gap, gui->mode,
 		       si->cursorclef);
 	}
     }
       /* End cursor drawing */
 
-
+  itp->last_gap = extra;
   /* Now quite possibly update the mark */
 
   if (si->firststaffmarked == itp->staffnum
@@ -514,7 +519,7 @@ draw_measure (cairo_t *cr, measurenode * curmeasure, gint x, gint y,
     {
       /* That is, the cursor's at the beginning of this blank measure */
       si->cursoroffend = FALSE; 
-      draw_cursor (cr, si, x, y, gui->mode, itp->clef->type);
+      draw_cursor (cr, si, x, y, 0, gui->mode, itp->clef->type);
       memcpy (si->cursoraccs, itp->curaccs, SEVENGINTS);
       si->cursorclef = itp->clef->type;     
     }
@@ -724,6 +729,11 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
 
   cairo_save(cr);
   }//if cr
+
+  if((gui->si->smf) && (itp->startobj==NULL) && (itp->startposition<=0) && (si->leftmeasurenum==1))
+    itp->startposition = x;
+
+
   /* Loop that will draw each measure. Basically a for loop, but was uglier
    * when written that way.  */
   itp->curmeasure =
@@ -752,9 +762,6 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
   while ( (!itp->line_end)  //       itp->measurenum <= si->rightmeasurenum+1
 	 && itp->measurenum <= g_list_length (thestaff->measures))
     {
-      
-
-
       if( x + GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE >
 	  (int) (gui->scorearea->allocation.width/gui->si->zoom - (RIGHT_MARGIN + KEY_MARGIN + si->maxkeywidth + SPACE_FOR_TIME)))
 	if(itp->curmeasure->next) {
@@ -762,7 +769,7 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
 	  // if(Denemo.gui->si->playingnow)
 	  //	continue;//don't show grayed out measures while playing.
 	}
-      
+      itp->last_gap = 0;
       draw_measure (cr, itp->curmeasure, x, y, gui, itp);
 
       x += GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE;
@@ -914,6 +921,7 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
 
   itp.highy = 0;//in case there are no objects...
   itp.lowy = 0;
+  itp.last_gap = 0;
   itp.last_midi = NULL;
   itp.playposition = -1;
   itp.startposition = -1;
@@ -923,9 +931,11 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
 
   if(gui->si->smf) {
     itp.startobj =
-      get_obj_for_start_time(gui->si->smf, gui->si->start_time);
+      get_obj_for_end_time(gui->si->smf, gui->si->start_time - 0.001);
+    // g_print("start %p\n", itp.startobj);
+
     itp.endobj =
-      get_obj_for_end_time(gui->si->smf, gui->si->end_time);
+      get_obj_for_start_time(gui->si->smf, gui->si->end_time - 0.001);
     //g_print("Start time %p %f end time %p %f\n", itp.startobj, si->start_time, itp.endobj, si->end_time);
   }
   cairo_t *cr = widget?gdk_cairo_create( gui->pixmap ): NULL;
