@@ -16,9 +16,6 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <fcntl.h>
-
-#include "lyparserfuncs.h"
-/*#include "lyparser.h"*/
 #include "exportlilypond.h"
 #include "print.h"
 #include "scoreops.h"
@@ -813,7 +810,7 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 	numdots = pchord->numdots;
 	is_chordmode = FALSE;
 
-	if(!curobj->isinvisible) {
+	//	if(!curobj->isinvisible) {
 	    if((!*pgrace_status) && pchord->is_grace) {
 	      *pgrace_status = TRUE;
 	      g_string_append_printf (ret,"\\grace {  ");
@@ -821,16 +818,8 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 		g_string_append_printf (figures, "\\grace {");
 	      if(fakechords->len)
 		g_string_append_printf (fakechords, "\\grace {");
-	    } else  
-	      if ((!pchord->is_grace) && *pgrace_status) {
-		*pgrace_status = FALSE, g_string_append_printf (ret,"} ");
-		if(figures->len)
-		  g_string_append_printf (figures, "}");
-		if(fakechords->len)
-		  g_string_append_printf (fakechords, "}");
-
-	      }
-	  }
+	    } 
+	    //	  }
 	GList *g = pchord->directives;
 	for(;g;g=g->next) {
 	  DenemoDirective *directive = (DenemoDirective *)g->data;
@@ -1072,9 +1061,6 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 	      g_string_append_printf (ret, "(");
 	    if (pchord->is_tied)
 	      g_string_append_printf (ret, " ~");
-
-
-	
 	  
 	    outputret;
 
@@ -1090,6 +1076,18 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 	    insert_editable(&directive->postfix, directive->postfix->str, iter, invisibility, gui);
 	  }
 	}
+
+
+	if ((pchord->is_grace & ENDGRACE) && *pgrace_status) {
+	  *pgrace_status = FALSE, g_string_append_printf (ret,"} ");
+	  if(figures->len)
+	    g_string_append_printf (figures, "}");
+	  if(fakechords->len)
+	    g_string_append_printf (fakechords, "}");
+	}
+	
+
+
 	break;
       case CLEF:
 	{gboolean override = get_lily_override(((clef *) curobj->object)->directives);
@@ -1642,7 +1640,7 @@ outputStaff (DenemoGUI *gui, DenemoScore * si, DenemoStaff * curstaffstruct,
 	    if((curobjnode!=NULL) && ((curobj == NULL) || curobj->type!=LILYDIRECTIVE)) /* if it ends in a lilydirective, the user may want to choose their own barline style, let them */
 	    {
 	      if (curmeasure->next)
-		g_string_append_printf(endstr,"%s", "%|\n");
+		g_string_append_printf(endstr,"%s", "\\Barline\n");
 	      else
 		g_string_append_printf(endstr, "%s"," \\bar \"|.\"\n");
 	    }
@@ -2083,7 +2081,9 @@ output_score_to_buffer (DenemoGUI *gui, gboolean all_movements, gchar * partname
     }
   }//end of standard prolog
 
-  {
+    {//Score prefix
+      //Default value for barline = barline check
+      gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter,  "\nBarline = |\n", -1, INEDITABLE, NULL, NULL);
   GList *g = gui->lilycontrol.directives;
   for(;g;g=g->next) {
     DenemoDirective *directive = g->data;
