@@ -9,8 +9,6 @@ void
 separate_fakechord_elements (gchar *fakechord, DenemoObject *curObj);
 
 void 
-fakechord_insert(GtkAction *action, DenemoGUI *gui);
-//DenemoObject *
-//newfigure (gint baseduration, gint numdots, gchar *figs);
+fakechord_insert(GtkAction *action, gpointer param);
 
 //#endif
