@@ -14,5 +14,6 @@ void
 figure_insert(GtkAction *action, gpointer param);
 DenemoObject *
 newfigure (gint baseduration, gint numdots, gchar *figs);
-
+void delete_figured_bass  (GtkAction *action, gpointer param);
+void hide_figured_bass  (GtkAction *action, gpointer param);
 #endif
