@@ -1,9 +1,11 @@
-/*	file.cpp
+/*	file.c
+ * License: this file may be used under the FSF GPL version 3 or later
  * 	Denemo File IO 
  *
  * 	for Denemo, a gtk+ frontend to GNU Lilypond
  * 	(c) Adam Tee, Matthew Hiller 2000-2005
  * 	(c) University of Leeds 2000-2005
+ *      (c) Richard Shann 2010
  */
 
 #include "calculatepositions.h"
@@ -21,10 +23,10 @@
 #include "exportxml.h"
 #include "exportmidi.h"
 #include "importxml.h"
+#include "importmusicxml.h"
 #include "exportcsound.h"
 #include "importmidi.h"
-#include "lyparserfuncs.h"
-/*#include "lyparser.h"*/
+
 #include "prefops.h"
 #include "binreloc.h"
 #include "view.h"
@@ -71,7 +73,8 @@ static struct FileFormatData supported_import_file_formats[] = {
   {"*.dnm", N_("Denemo XML format (*.dnm)"), ".dnm"},
   {"*.ly", N_("Lilypond (*.ly)"), ".ly"},
   {"*.mid", N_("Midi (*.mid)"), ".mid"},
-  {"*.midi", N_("Midi (*.midi)"), ".midi"}
+  {"*.midi", N_("Midi (*.midi)"), ".midi"},
+  {"*.mxml", N_("Music XML (*.mxml)"), ".mxml"}
 };
 
 
@@ -217,7 +220,24 @@ static void      update_file_selection_path (gchar *file) {
   file_selection_path = g_path_get_dirname(file);
 }
 
+gint lyinput(gchar *filename, DenemoGUI *gui) {
+  gchar *path = g_path_get_dirname(filename);
+  gchar *base = g_path_get_basename(filename);
+#ifdef G_OS_WIN32
+  gchar *call = g_strescape(path, "");
+  call = g_strdup_printf("%s%s%s%s%s", "(debug-set! stack 200000) (lyimport::load-file \"", call, "\\\\\" \"", base,"\")" );
+  g_print("Calling %s\n", call);
+#else
+  gchar *call = g_strdup_printf("%s%s%c%s%s%s", "(lyimport::load-file \"", path, G_DIR_SEPARATOR,"\" \"", base,"\")" );
+#endif
 
+  
+  call_out_to_guile(call);
+  g_free(path);
+  g_free(base);
+  g_free(call);
+  return 0;
+}
 
 
 /**
@@ -233,16 +253,19 @@ open_for_real (gchar * filename, DenemoGUI * gui, gboolean template, ImportType
   gint result;
   gboolean xml = FALSE;
   result = 1;//FAILURE
+#define EXISTS(extension) (strcmp (filename + strlen (filename) - strlen(extension), extension) == 0)
   if(g_file_test(filename, G_FILE_TEST_EXISTS)) {
-    if (strcmp (filename + strlen (filename) - 7, ".denemo") == 0)
+    if(EXISTS(".denemo"))
       xml=TRUE, result = importXML (filename, gui, type);
-    else if (strcmp (filename + strlen (filename) - 4, ".dnm") == 0)
+    else if(EXISTS(".dnm"))
       xml=TRUE, result = importXML (filename, gui, type);
-    else if (strcmp (filename + strlen (filename) - 3, ".ly") == 0)
+    else if(EXISTS(".ly"))
       result = lyinput (filename, gui);
-    else if (strcmp (filename + strlen (filename) - 4, ".mid") == 0 ||
-	     strcmp (filename + strlen (filename) - 5, ".midi") == 0)
+    else if(EXISTS(".mxml"))
+      result = mxmlinput (filename, gui);
+    else if(EXISTS(".mid") || EXISTS(".midi"))
       result = importMidi (filename, gui);
+#undef EXISTS
   }
   if (result == 0)
     {
