@@ -200,10 +200,12 @@ static temperament WerckmeisterIV = {
   }
 };
 
+
 static temperament *PR_temperament=&Equal; /* the currently used temperament */
 
 static temperament *temperaments[] = {&Equal, &Meantone, &WerckmeisterIV, &Lehman, &Rameau};
 
+
 static void switch_back_to_main_window(void) {
 
     gtk_window_present(GTK_WINDOW(Denemo.window));
@@ -257,7 +259,6 @@ static gchar *alteration_name(gint alteration) {
 
 
 
-
 /* returns the note names currently set for the given temperament
  caller must free the string */
 static gchar * notenames(gpointer p) {
@@ -279,11 +280,47 @@ static gchar * notenames(gpointer p) {
   return str;
 }
 
+gchar *determine_interval(gint bass, gint harmony){
+  gint bass_octave, harmony_octave;
+  gdouble deviation;
+  gint semitones = harmony - bass;
+  gint *accs = ((DenemoStaff*)Denemo.gui->si->currentstaff->data)->keysig.accs;
+ notepitch bassnote = PR_temperament->notepitches[bass%12];
+ notepitch harmonynote = PR_temperament->notepitches[harmony%12];
+ gint interval =  harmonynote.spec.step - bassnote.spec.step + 1;
+ if(interval<2)interval += 7;
+ if(interval==2 && semitones>12) interval=9;
+ gint inflection = harmonynote.spec.alteration - accs[harmonynote.spec.step];
+
+
+// g_print("Bass %d harmony %d\nInterval is %d, semitones is %d cf (%d, %d)  \n keyaccs of bass note %d of harmony %d\ninflection %d\n", bass, harmony, interval, semitones, bassnote.spec.alteration, harmonynote.spec.alteration, accs[bassnote.spec.step], accs[harmonynote.spec.step], inflection);
+ gchar *modifier="";
+ if(interval==5 && semitones==6)
+   modifier = "/";
+     else 
+       if(inflection<0) modifier = "-";
+       else
+	 if(inflection>0) modifier = "+";
+ if(harmony<bass)
+   return g_strdup_printf("%s", "0");//A non printing figure
+ if(interval==3 && inflection)
+   return g_strdup_printf("%c%s", '_', modifier);
+ else
+   return g_strdup_printf("%d%s", interval, modifier);
+}
+
+
 static gchar *nameof(gint notenumber) {
  return g_strdup_printf("%c%s", step_name(PR_temperament->notepitches[notenumber].spec.step), alteration_name(PR_temperament->notepitches[notenumber].spec.alteration));
 }
 
-
+//Caller must free
+gchar *sharpest(void) {
+  return nameof(PR_temperament->sharp);
+}
+gchar *flattest(void) {
+  return nameof(PR_temperament->flat);
+}
 
 /* returns an opaque id for the user's default temperament
  FIXME user prefs */
@@ -396,6 +433,21 @@ if (Denemo.prefs.midi_audio_output == Fluidsynth)
 }
 
 
+//Computes the mid_c_offset and enshift for the MIDI notenum passed in
+void
+notenum2enharmonic (gint notenum, gint *poffset, gint *penshift) {
+
+  *penshift = notenum % 12;  
+  temperament *t = PR_temperament;
+  
+  *poffset = t->notepitches[*penshift].spec.step;
+  *penshift =  t->notepitches[*penshift].spec.alteration;
+  return;
+}
+
+
+
+#ifdef _HAVE_PORTAUDIO_
 static void sound_click(void) {
   if(PR_click)
     signal_measure_end();
@@ -643,19 +695,6 @@ static notepitch * determine_note(gdouble pitch, temperament *t, gint* which_oct
 }
 
 
-//Computes the mid_c_offset and enshift for the MIDI notenum passed in
-void
-notenum2enharmonic (gint notenum, gint *poffset, gint *penshift) {
-
-  *penshift = notenum % 12;  
-  temperament *t = PR_temperament;
-  
-  *poffset = t->notepitches[*penshift].spec.step;
-  *penshift =  t->notepitches[*penshift].spec.alteration;
-  return;
-}
-
-
 
 
 static void display_pitch(double note, DenemoGUI *gui) {
@@ -983,6 +1022,7 @@ static void  temperament_changed_callback (GtkComboBox *combobox,  GtkListStore
   g_string_assign(Denemo.prefs.temperament, PR_temperament->name);
 }
 
+#endif
 GtkWidget *get_enharmonic_frame(void) {
   static GtkWidget *frame;
   if(frame==NULL) {
@@ -1015,7 +1055,7 @@ GtkWidget *get_enharmonic_frame(void) {
   return frame;
 }
 
-
+#ifdef _HAVE_PORTAUDIO_
 
 static void create_pitch_recognition_window(DenemoGUI *gui) {
   GtkWidget *hbox, *hbox2;
@@ -1406,31 +1446,11 @@ gboolean pitch_entry_active(DenemoGUI *gui) {
   return (PR_gui == gui) && PR_enable;
 }
 
-gchar *determine_interval(gint bass, gint harmony){
-  gint bass_octave, harmony_octave;
-  gdouble deviation;
-  gint semitones = harmony - bass;
-  gint *accs = ((DenemoStaff*)Denemo.gui->si->currentstaff->data)->keysig.accs;
- notepitch bassnote = PR_temperament->notepitches[bass%12];
- notepitch harmonynote = PR_temperament->notepitches[harmony%12];
- gint interval =  harmonynote.spec.step - bassnote.spec.step + 1;
- if(interval<2)interval += 7;
- if(interval==2 && semitones>12) interval=9;
- gint inflection = harmonynote.spec.alteration - accs[harmonynote.spec.step];
+#else
+gboolean pitch_entry_active(DenemoGUI *gui){ return 0; }
 
-
-// g_print("Bass %d harmony %d\nInterval is %d, semitones is %d cf (%d, %d)  \n keyaccs of bass note %d of harmony %d\ninflection %d\n", bass, harmony, interval, semitones, bassnote.spec.alteration, harmonynote.spec.alteration, accs[bassnote.spec.step], accs[harmonynote.spec.step], inflection);
- gchar *modifier="";
- if(interval==5 && semitones==6)
-   modifier = "/";
-     else 
-       if(inflection<0) modifier = "-";
-       else
-	 if(inflection>0) modifier = "+";
- if(harmony<bass)
-   return g_strdup_printf("%s", "0");//A non printing figure
- if(interval==3 && inflection)
-   return g_strdup_printf("%c%s", '_', modifier);
- else
-   return g_strdup_printf("%d%s", interval, modifier);
-}
+gint setup_pitch_input(void){ return -1; }
+void start_pitch_input(void) {}
+int stop_pitch_input(void) { return 0; }
+void clear_overlay(GtkAction *action, gpointer param) {}
+#endif
