@@ -31,10 +31,12 @@ struct callbackdata
   GtkWidget *immediateplayback;
   GtkWidget *modal;
   GtkWidget *cursor_highlight;
+  GtkWidget *persistence;
   GtkWidget *startmidiin;
   GtkWidget *applytoselection;
   GtkWidget *saveparts;
   GtkWidget *autosave;
+  GtkWidget *toolbar;
   GtkWidget *notation_palette;
   GtkWidget *rhythm_palette;
   GtkWidget *object_palette;
@@ -182,6 +184,7 @@ set_preferences (struct callbackdata *cbdata)
   
   ASSIGNBOOLEAN(immediateplayback)
   ASSIGNBOOLEAN(modal)
+  ASSIGNBOOLEAN(persistence)
   ASSIGNBOOLEAN(cursor_highlight)
   ASSIGNBOOLEAN(startmidiin)
   ASSIGNBOOLEAN(applytoselection)
@@ -194,6 +197,7 @@ set_preferences (struct callbackdata *cbdata)
   ASSIGNBOOLEAN(lyrics_pane)
   ASSIGNBOOLEAN(visible_directive_buttons)
   ASSIGNBOOLEAN(autoupdate)
+  ASSIGNBOOLEAN(toolbar)
   ASSIGNBOOLEAN(notation_palette)
   ASSIGNBOOLEAN(rhythm_palette)
   ASSIGNBOOLEAN(object_palette)
@@ -227,6 +231,12 @@ midi_audio_tab_update(GtkWidget *box, gpointer data)
       gtk_widget_hide(cbdata->DM);
     gtk_widget_show(cbdata->pas);
   }
+  else if (output == None){
+    gtk_widget_hide(cbdata->fs);
+    if(cbdata->DM)
+      gtk_widget_hide(cbdata->DM);
+  }
+
 }
 
 void
@@ -346,7 +356,10 @@ preferences_change (GtkAction *action, gpointer param)
   BOOLEANENTRY("Highlight the cursor", cursor_highlight); 
   //Doesnt GList need to be freed
   GList *output_option_list = NULL;
+  output_option_list = g_list_append (output_option_list, (gpointer) None);
+#ifdef _HAVE_PORTAUDIO_
   output_option_list = g_list_append (output_option_list, (gpointer) Portaudio);
+#endif
 #ifdef _HAVE_JACK_
   output_option_list = g_list_append (output_option_list, (gpointer) Jack);
 #endif 
@@ -371,7 +384,7 @@ preferences_change (GtkAction *action, gpointer param)
   gtk_widget_show (field);\
   cbdata.field = field;
 
-
+  BOOLEANENTRY("Display general toolbar", toolbar);
   BOOLEANENTRY("Display Note/Rest entry toolbar", notation_palette);
   BOOLEANENTRY("Display articulation palette", articulation_palette);
   BOOLEANENTRY("Display Controls for Incoming MIDI signals", midi_in_controls);
@@ -424,6 +437,7 @@ preferences_change (GtkAction *action, gpointer param)
    */
   NEWPAGE("Misc");
   BOOLEANENTRY("Use Denemo modally", modal);   
+  BOOLEANENTRY("Re-use last settings on startup", persistence);   
   DOUBLEENTRY_LIMITS(_("Playback Display Refresh"), display_refresh, 0.001, 0.5, 0.002);
   INTENTRY_LIMITS(_("Page Turn Steps"), animation_steps, 1, 200);
 
@@ -564,6 +578,12 @@ preferences_change (GtkAction *action, gpointer param)
       gtk_widget_hide(DM);
     gtk_widget_show(pas);
   }
+  else if (Denemo.prefs.midi_audio_output == None){
+    gtk_widget_hide(fs);
+    gtk_widget_hide(pas);
+    if(DM)
+      gtk_widget_hide(DM);
+  }
 
   audio_cbdata.main_vbox = main_vbox;
   audio_cbdata.fs = fs;
