@@ -50,6 +50,7 @@ static gint output=-1;
 static gint errors=-1;
 static   GError *lily_err = NULL;
 
+
 /*** 
  * make sure lilypond is in the path defined in the preferences
  */
@@ -102,20 +103,22 @@ version_check(lilyversion base, lilyversion installed)
 lilyversion
 string_to_lilyversion(char *string)
 {
-  lilyversion version;
+  lilyversion version = { 2, 0};
   char **token;
   const char delimiters[] = ".";
-
+  if(string==NULL)
+    return version;
   /* split string */
   token = g_strsplit(string, delimiters, 2);
 
   /* get major version number */
-  version.major = atoi(token[0]);
-
+  if(token[0])
+    version.major = atoi(token[0]);
   /* get minor version number */
-  version.minor = atoi(token[1]);
-
-  printf("\nstring_to_lilyversion() major = %d minor = %d\n",version.major, version.minor);
+  if(token[1])
+    version.minor = atoi(token[1]);
+  g_strfreev(token);
+  //intf("\nstring_to_lilyversion() major = %d minor = %d\n",version.major, version.minor);
   return version;
 }
 
@@ -138,10 +141,13 @@ regex_parse_version_number (const gchar *string)
   g_regex_unref (regex);
   return g_string_free(lilyversion, FALSE); 	  
 }
-
+#define INSTALLED_LILYPOND_VERSION "2.13" /* FIXME set via gub */
 gchar *
 get_lily_version_string (void)
 {
+#ifdef G_OS_WIN32
+  return INSTALLED_LILYPOND_VERSION;
+#else
   GError *error = NULL;
   gchar *version_string;
   double d;
@@ -164,10 +170,14 @@ get_lily_version_string (void)
   &standard_output,	/*standard output*/
   NULL,	/*standard error*/
   &error);
-
-  read(standard_output, buf, sizeof(buf));
-  return regex_parse_version_number(buf);
-
+  if(error==NULL) {
+    read(standard_output, buf, sizeof(buf));
+    return regex_parse_version_number(buf);
+  } else {
+    g_warning ("%s", error->message);
+    g_error_free (error);
+  }
+#endif
 }
 int
 check_lily_version (gchar *version)
@@ -399,7 +409,7 @@ run_lilypond(gchar *filename, DenemoGUI *gui){
   };
   gchar *png_arguments2[] = {
     Denemo.prefs.lilypath->str,
-    "--png",
+   "--png",
     "-b",
     "eps",
     resolution,
@@ -437,7 +447,12 @@ run_lilypond(gchar *filename, DenemoGUI *gui){
   };
   if (!gui->lilycontrol.excerpt)	  
 	  arguments = pdf;
-  
+  if(lily_err) {
+    g_warning("Old error message from launching lilypond still present - message was %s\nDiscarding...\n", lily_err->message);
+    g_error_free(lily_err);
+    lily_err = NULL;
+
+  }
   g_spawn_async_with_pipes (locatedotdenemo (),		/* dir */
 		arguments, NULL,	/* env */
 		G_SPAWN_SEARCH_PATH  | G_SPAWN_DO_NOT_REAP_CHILD, NULL,	/* child setup func */
@@ -445,12 +460,22 @@ run_lilypond(gchar *filename, DenemoGUI *gui){
 		&printpid,
 	        NULL,
 		NULL,		/* stdout */
+#ifdef G_OS_WIN32
+			    NULL,
+#else
 		&errors,		/* stderr */
+#endif
 		&lily_err);
-  if (gui->lilycontrol.excerpt == TRUE)
-    g_child_watch_add (printpid, (GChildWatchFunc)open_pngviewer  /*  GChildWatchFunc function */, filename);
-  else
-    g_child_watch_add (printpid, (GChildWatchFunc)open_pdfviewer  /*  GChildWatchFunc function */, filename);
+  if(lily_err) {
+    g_warning("Error launching lilypond message is %s\n", lily_err->message);
+    g_error_free(lily_err);
+    lily_err = NULL;
+  } else {
+    if (gui->lilycontrol.excerpt == TRUE)
+      g_child_watch_add (printpid, (GChildWatchFunc)open_pngviewer  /*  GChildWatchFunc function */, filename);
+    else
+      g_child_watch_add (printpid, (GChildWatchFunc)open_pdfviewer  /*  GChildWatchFunc function */, filename);
+  }
 }
 
 /* Run the LilyPond interpreter on the file (filename).ly
@@ -923,6 +948,7 @@ printall(void) {
 				     GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 				     "%s", error->message);
     g_error_free (error);
+    error = NULL;
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
   }
@@ -1023,6 +1049,7 @@ printview_finished(GPid pid, gint status, gboolean preview_only) {
      g_warning (_("Could not load the print preview:\n%s\n"),
                  error->message);
      g_error_free (error);
+     error = NULL;
      gui->pixbuf = NULL;
    } else {
      gboolean ret;
@@ -1123,10 +1150,17 @@ void refresh_print_view (gboolean preview_only) {
 		 &printviewpid,
 		 NULL,
 		 NULL,		/* stdout */
+#ifdef G_OS_WIN32
+			    NULL,
+#else
 	         &printpreview_errors,		/* stderr */
+#endif
 		 &error);
   g_free(lilyfile);
-  g_child_watch_add (printviewpid, (GChildWatchFunc)printview_finished  /*  GChildWatchFunc function */, (gpointer)preview_only);
+  if(error==NULL)
+    g_child_watch_add (printviewpid, (GChildWatchFunc)printview_finished  /*  GChildWatchFunc function */, (gpointer)preview_only);
+  else
+    g_warning ("%s", error->message);
 }
 
 /* callback to print whole of score */
