@@ -418,6 +418,8 @@ cuttobuffer (DenemoScore * si, gboolean copyfirst)
   isoffleftside(Denemo.gui);
   isoffrightside(Denemo.gui);
 
+  score_status(Denemo.gui, TRUE);
+
   /*   isoffleftside;  */
   /*find_xes_in_all_measures (si);
     nudgerightward (Denemo.gui);
@@ -752,7 +754,10 @@ set_point (DenemoGUI * gui)
   }
 }
 
-
+gboolean
+mark_status (void) {
+  return Denemo.gui->si->markstaffnum!=0;
+}
 
 /**
  * unset_mark
@@ -958,6 +963,7 @@ void
 pastewrapper (GtkAction *action, DenemoScriptParam *param)
 {  
   call_out_to_guile("(DenemoPaste)");
+  score_status(Denemo.gui, TRUE);
 }
 
 
