@@ -22,7 +22,7 @@
 #else
 #include "binreloc.h"
 #endif
-
+#include "pitchentry.h"
 
 
 void add_font_directory(gchar *fontpath) {
@@ -33,12 +33,19 @@ void add_font_directory(gchar *fontpath) {
 #endif
 }
 
-
+#ifdef G_OS_WIN32
+gboolean CoInitializeExCalled = FALSE;
+#endif
 
 gboolean run_file_association(gchar *filename) {
 #ifdef G_OS_WIN32
-  g_print("Running ShellExecute %s\n", filename);
-  CoInitializeEx(NULL, COINIT_APARTMENTTHREADED | COINIT_DISABLE_OLE1DDE);
+  gint value = 0;
+  if(!CoInitializeExCalled) {
+    value = CoInitializeExCalled = TRUE;
+    CoInitializeEx(NULL, COINIT_APARTMENTTHREADED | COINIT_DISABLE_OLE1DDE);
+    g_print("coinit returned %d\n", value);
+  }
+  g_print("Running ShellExecute %s \n", filename);
   return ShellExecute(NULL, NULL, filename, NULL, NULL, 0) > 32/* value above 32 indicating success */;
 #else
   g_warning("No file assoc code - set pref in externals tab of prefs dialog");
@@ -970,20 +977,28 @@ void write_status(DenemoGUI *gui) {
   } else
     selection = g_strdup_printf("Cursor not on any object");
 
-  gchar *status;
+  GString  *status = g_string_new(_("Movement"));
 
-  status = "Movement";
   gint index = g_list_index(gui->movements, gui->si);
-  if((gui->si->smfsync == gui->si->changecount) && (GTK_WIDGET_VISIBLE (Denemo.playback_control)))
-    status = g_strdup_printf("%s %d: %s: %d min %.2f sec %.2f %.2f", status, index+1, selection, minutes, seconds, early, late);
+  g_string_printf(status, " %d: %s: ", index+1, selection);
+  if(gui->si->smf && (gui->si->smfsync == gui->si->changecount) && Denemo.prefs.playback_controls)
+    g_string_append_printf(status, "%d min %.2f sec %.2f %.2f", minutes, seconds, early, late);
   else
-    status = g_strdup_printf("%s %d: %s: Staff %d Measure %d Object %d %s", status, index+1, selection, gui->si->currentstaffnum, gui->si->currentmeasurenum, gui->si->cursor_x, gui->si->cursor_appending?"Appending":"Not Appending"/*not understood this one... , gui->si->cursoroffend?"Off End":"Not Off End" */);
+    g_string_append_printf(status, " Staff %d Measure %d Object %d %s", gui->si->currentstaffnum, gui->si->currentmeasurenum, gui->si->cursor_x, gui->si->cursor_appending?"Appending":"Not Appending"/*not understood this one... , gui->si->cursoroffend?"Off End":"Not Off End" */);
   
+  if(Denemo.prefs.midi_in_controls) {
+      gchar *thesharp = sharpest();
+      gchar *theflat = flattest();
+      g_string_append_printf(status, " |%s - %s|", theflat, thesharp);
+      g_free(theflat);
+      g_free(thesharp);
+  }
+      
   g_free(selection);
   gtk_statusbar_pop(GTK_STATUSBAR (Denemo.statusbar), Denemo.status_context_id);
   gtk_statusbar_push(GTK_STATUSBAR (Denemo.statusbar), Denemo.status_context_id,
-		     status);
-  g_free(status);
+		     status->str);
+  g_string_free(status, TRUE);
 }
 
 void
@@ -1199,3 +1214,24 @@ gchar *substitute_extension(gchar *name, gchar *extension) {
   (void)remove_extension(name);
   return g_strdup_printf("%s.%s", name, extension);
 }
+
+enum clefs
+cleftypefromname (gchar * str)
+{
+  enum clefs ret = DENEMO_TREBLE_CLEF;
+
+  if (g_strcasecmp (str, "treble") == 0)
+    ret = DENEMO_TREBLE_CLEF;
+  else if (g_strcasecmp (str, "bass") == 0)
+    ret = DENEMO_BASS_CLEF;
+  else if (g_strcasecmp (str, "alto") == 0)
+    ret = DENEMO_ALTO_CLEF;
+  else if (g_strcasecmp (str, "\"g_8\"") == 0)
+    ret = DENEMO_G_8_CLEF;
+  else if (g_strcasecmp (str, "tenor") == 0)
+    ret = DENEMO_TENOR_CLEF;
+  else if (g_strcasecmp (str, "soprano") == 0)
+    ret = DENEMO_SOPRANO_CLEF;
+  g_free (str);
+  return ret;
+}
